@@ -1,18 +1,7 @@
 /*
- * Copyright 2016 ROSA
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2016 ROSA
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef EXTERNALPROGRESSBAR_H
 #define EXTERNALPROGRESSBAR_H
@@ -31,7 +20,7 @@ protected:
     ExternalProgressBarPrivate* const d_ptr;
 
 public:
-    ExternalProgressBar(QWidget* mainWindow);
+    explicit ExternalProgressBar(QWidget* mainWindow);
     ~ExternalProgressBar();
 
     // Initializes the external progress bar and sets its limits
